Package: Directional
Type: Package
Title: A Collection of Functions for Directional Data Analysis
Version: 7.8
Date: 2026-09-02
Authors@R: c( person(given = "Michail", family = "Tsagris", role = c("aut", "cre"), email = "mtsagris@uoc.gr"),
               person(given = "Giorgos", family = "Athineou", role = "aut"), 
               person(given = "Christos", family = "Adam", role = "aut"),
               person(given = "Zehao", family = "Yu", role = "aut"),
               person(given = "Anamul", family = "Sajib", role = "ctb"),
               person(given = "Eli", family = "Amson", role = "ctb"),
               person(given = c("Micah", "J."), family = "Waldstein", role = "ctb"),
               person(given = "Panagiotis", family = "Papastamoulis", role = "ctb") )
Maintainer: Michail Tsagris <mtsagris@uoc.gr>
Description: A collection of functions for directional data (including massive data, with millions of observations) analysis. 
             Hypothesis testing, discriminant and regression analysis, MLE of distributions and more are included. 
			 The standard textbook for such data is the "Directional Statistics" by Mardia, K. V. and Jupp, P. E. (2000). 
			 Other references include:
			 a) Paine J.P., Preston S.P., Tsagris M. and Wood A.T.A. (2018). "An elliptically symmetric angular Gaussian distribution". Statistics and Computing 28(3): 689-697. <doi:10.1007/s11222-017-9756-4>. 
			 b) Tsagris M. and Alenazi A. (2019). "Comparison of discriminant analysis methods on the sphere". Communications in Statistics: Case Studies, Data Analysis and Applications 5(4):467--491. <doi:10.1080/23737484.2019.1684854>. 
			 c) Paine J.P., Preston S.P., Tsagris M. and Wood A.T.A. (2020). "Spherical regression models with general covariates and anisotropic errors". Statistics and Computing 30(1): 153--165. <doi:10.1007/s11222-019-09872-2>. 
			 d) Tsagris M. and Alenazi A. (2024). "An investigation of hypothesis testing procedures for circular and spherical mean vectors". Communications in Statistics-Simulation and Computation, 53(3): 1387--1408. <doi:10.1080/03610918.2022.2045499>. 
			 e) Yu Z. and Huang X. (2024). A new parameterization for elliptically symmetric angular Gaussian distributions of arbitrary dimension. Electronic Journal of Statistics, 18(1): 301--334. <doi:10.1214/23-EJS2210>. 
			 f) Tsagris M. and Alzeley O. (2025). "Circular and spherical projected Cauchy distributions: A Novel Framework for Circular and Directional Data Modeling". Australian & New Zealand Journal of Statistics, 67(1): 77--103. <doi:10.1111/anzs.12434>. 
			 g) Tsagris M., Papastamoulis P. and Kato S. (2025). "Directional data analysis: spherical Cauchy or Poisson kernel-based distribution". Statistics and Computing, 35:51. <doi:10.1007/s11222-025-10583-0>.
			 h) Alzeley O. and Tsagris (2026). "On the generalized circular projected Cauchy distribution". Mathematics, 14(11): 1934.  <doi:10.3390/math14111934>.
License: GPL (>= 2)
Imports: bigstatsr, doParallel, foreach, ggplot2, grDevices, magrittr,
        parallel, Rfast, Rfast2, Rnanoflann, rangen, rgl,
        rnaturalearth, sf
Suggests: bigreadr
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2026-09-02 08:56:18 UTC; mtsag
Author: Michail Tsagris [aut, cre],
  Giorgos Athineou [aut],
  Christos Adam [aut],
  Zehao Yu [aut],
  Anamul Sajib [ctb],
  Eli Amson [ctb],
  Micah J. Waldstein [ctb],
  Panagiotis Papastamoulis [ctb]
Repository: CRAN
Date/Publication: 2026-09-02 12:20:22 UTC
